#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SQRT_2O_2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SQRT_2O_2_HPP_INCLUDED

#include <boost/simd/constant/include/constants/sqrt_2o_2.hpp>

#endif
